@@ -66,7 +66,7 @@ class Connector(object):
     registered_clowder = list()
 
     def __init__(self, extractor_name, extractor_info, check_message=None, process_message=None, ssl_verify=True,
-                 mounted_paths=None, clowder_url=None):
+                 mounted_paths=None, clowder_url=None, max_retry=10):
         self.extractor_name = extractor_name
         self.extractor_info = extractor_info
         self.check_message = check_message
@@ -77,6 +77,7 @@ class Connector(object):
         else:
             self.mounted_paths = mounted_paths
         self.clowder_url = clowder_url
+        self.max_retry = max_retry
 
         filename = 'notifications.json'
         self.smtp_server = None
@@ -376,8 +377,9 @@ class Connector(object):
             logger.debug(emailaddrlist)
         # source_host is original from the message, host is remapped to CLOWDER_URL if given
         source_host = body.get('host', '')
-        host = self.clowder_url if self.clowder_url is not None else source_host
+        host = self.clowder_url if self.clowder_url else source_host
         if host == '' or source_host == '':
+            logging.error("Host is empty, this is bad.")
             return
         if not source_host.endswith('/'): source_host += '/'
         if not host.endswith('/'): host += '/'
@@ -385,6 +387,7 @@ class Connector(object):
         retry_count = 0 if 'retry_count' not in body else body['retry_count']
         resource = self._build_resource(body, host, secret_key)
         if not resource:
+            logging.error("No resource found, this is bad.")
             return
 
         # register extractor
@@ -488,7 +491,7 @@ class Connector(object):
         except Exception as exc:  # pylint: disable=broad-except
             message = str(exc)
             logger.exception("[%s] %s", resource['id'], message)
-            if retry_count < 10:
+            if retry_count < self.max_retry:
                 message = "(#%s) %s" % (retry_count+1, message)
                 self.message_resubmit(resource, retry_count+1, message)
             else:
@@ -627,9 +630,9 @@ class RabbitMQConnector(Connector):
     def __init__(self, extractor_name, extractor_info,
                  rabbitmq_uri, rabbitmq_exchange=None, rabbitmq_key=None, rabbitmq_queue=None,
                  check_message=None, process_message=None, ssl_verify=True, mounted_paths=None,
-                 heartbeat=5*60, clowder_url=None):
+                 heartbeat=5*60, clowder_url=None, max_retry=10):
         super(RabbitMQConnector, self).__init__(extractor_name, extractor_info, check_message, process_message,
-                                                ssl_verify, mounted_paths, clowder_url)
+                                                ssl_verify, mounted_paths, clowder_url, max_retry)
         self.rabbitmq_uri = rabbitmq_uri
         self.rabbitmq_exchange = rabbitmq_exchange
         self.rabbitmq_key = rabbitmq_key
@@ -659,7 +662,6 @@ class RabbitMQConnector(Connector):
 
         # declare the queue in case it does not exist
         self.channel.queue_declare(queue=self.rabbitmq_queue, durable=True)
-        self.channel.queue_declare(queue='extractors.' + self.rabbitmq_queue, durable=True)
         self.channel.queue_declare(queue='error.'+self.rabbitmq_queue, durable=True)
 
         # register with an exchange
@@ -811,7 +813,7 @@ class RabbitMQBroadcast:
         self.channel.exchange_declare(exchange='extractors', exchange_type='fanout', durable=True)
 
         self.thread = threading.Thread(target=self.send_heartbeat)
-        self.thread.setDaemon(True)
+        self.thread.daemon = True
         self.thread.start()
 
     def stop_thread(self):
@@ -851,10 +853,10 @@ class RabbitMQHandler(Connector):
     """
 
     def __init__(self, extractor_name, extractor_info, job_id, check_message=None, process_message=None, ssl_verify=True,
-                 mounted_paths=None, clowder_url=None, method=None, header=None, body=None):
+                 mounted_paths=None, clowder_url=None, method=None, header=None, body=None, max_retry=10):
 
         super(RabbitMQHandler, self).__init__(extractor_name, extractor_info, check_message, process_message,
-                                              ssl_verify, mounted_paths, clowder_url)
+                                              ssl_verify, mounted_paths, clowder_url, max_retry)
         self.method = method
         self.header = header
         self.body = body
@@ -877,12 +879,12 @@ class RabbitMQHandler(Connector):
         }
         """
         self.thread = threading.Thread(target=self._process_message, args=(json_body,))
-        self.thread.setDaemon(True)
+        self.thread.daemon = True
         self.thread.start()
 
     def is_finished(self):
         with self.lock:
-            return self.thread and not self.thread.isAlive() and self.finished and len(self.messages) == 0
+            return self.thread and not self.thread.is_alive() and self.finished and len(self.messages) == 0
 
     def process_messages(self, channel, rabbitmq_queue):
         while self.messages:
@@ -976,9 +978,9 @@ class HPCConnector(Connector):
 
     # pylint: disable=too-many-arguments
     def __init__(self, extractor_name, extractor_info, picklefile, job_id=None,
-                 check_message=None, process_message=None, ssl_verify=True, mounted_paths=None):
+                 check_message=None, process_message=None, ssl_verify=True, mounted_paths=None, max_retry=10):
         super(HPCConnector, self).__init__(extractor_name, extractor_info, check_message, process_message,
-                                           ssl_verify, mounted_paths)
+                                           ssl_verify, mounted_paths, max_retry=max_retry)
         self.job_id = job_id
         self.picklefile = picklefile
         self.logfile = None
@@ -1035,8 +1037,8 @@ class LocalConnector(Connector):
 
     """
 
-    def __init__(self, extractor_name, extractor_info, input_file_path, process_message=None, output_file_path=None):
-        super(LocalConnector, self).__init__(extractor_name, extractor_info, process_message=process_message)
+    def __init__(self, extractor_name, extractor_info, input_file_path, process_message=None, output_file_path=None, max_retry=10):
+        super(LocalConnector, self).__init__(extractor_name, extractor_info, process_message=process_message, max_retry=max_retry)
         self.input_file_path = input_file_path
         self.output_file_path = output_file_path
         self.completed_processing = False
